#
# spec file for package nyxt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# WebExtension support is not included by default because it's unfinished
# and possibly prone to security issues.
%bcond_with webextensions

Name:           nyxt
Version:        3.6.1
Release:        bp156.1.44
Summary:        Keyboard-oriented, Common Lisp extensible web-browser
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Browsers
URL:            https://nyxt.atlas.engineer
Source:         nyxt-%{version}-source-with-submodules.tar.xz
Patch0:         so_ver_fix.patch
Requires:       enchant-tools
Requires:       glib-networking
Requires:       gsettings-desktop-schemas
Requires:       libfixposix4
Requires:       libwebkit2gtk-4_1-0
Requires:       xclip
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  sbcl
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libfixposix)
BuildRequires:  pkgconfig(webkit2gtk-4.1)
Conflicts:      nyxt-git

%description
Nyxt is a keyboard-oriented, extensible web-browser designed for power users.
It has familiar key-bindings (Emacs, VI, CUA), is fully configurable and
extensible in Lisp, and has powerful features for productive professionals.

%prep
%setup -q -c nyxt-%{version}
%patch0 -p1

%build

%if %{with webextensions}
make all web-extensions PREFIX=/usr LIBDIR=%{_libdir} NASDF_COMPRESS=T
%else
make all PREFIX=/usr LIBDIR=%{_libdir} NASDF_COMPRESS=T
%endif

%install

%make_install PREFIX=/usr LIBDIR=%{buildroot}/%{_libdir}

%if %{with webextensions}
strip -s %{buildroot}/%{_libdir}/nyxt/libnyxt.so
%endif

%files
%{_bindir}/nyxt
%if %{with webextensions}
%{_libdir}/nyxt/
%endif
%{_datadir}/nyxt/
%{_datadir}/icons/hicolor/*/apps/nyxt.png
%{_datadir}/applications/nyxt.desktop
%doc README.org
%license licenses/ASSET-LICENSE
%license licenses/SOURCE-LICENSE

%changelog
* Tue Aug 29 2023 Michael Pujos <pujos.michael@gmail.com>
- fixed missing dependencies
- Update to version 3.6.1:
  * Bug fixes
  - Fix clipboard facilities on X11 and Wayland
  - Fix dark-mode and the darken (UNBOUND) bookmarklet command
* Mon Aug 14 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to version 3.6.0:
  * Features
  - Add commands for importing history from Firefox, Google Chrome, Chromium,
    Brave and Vivaldi. For instance, import-history-from-firefox (UNBOUND)
  * Bug fixes
  - Fix keyscheme configuration via Common Settings Menu
  * UI/UX
  - Add Public Sans font and set it as the default
  - Redesign status buffer buttons
  - Minor review of start page
* Mon Jul 24 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to version 3.5.0:
  * Features
  - Add new quick start tutorial, accesible via command quick-start (UNBOUND)
  - Add hinting support for pages using Shadow DOMs
  - Add keybinding for command describe-any (f1 a)
  * Bug fixes
  - Fix status buffer history buttons
  - Fix bug in command repeat-key (UNBOUND)
  * UI/UX
  - Redesign start page
  - Fix styling of progress bar
  - Fix styling of prompt buffer's input area
* Mon Jul 10 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to version 3.4.0:
  * Features
  - Enable native spell-checking from WebKitGTK. The language can be set
    via command set-spell-check-languages. The list of dictionaries is
    provided by Enchant
  - Add prompt buffer keybindings for commands previous-page (UNBOUND) and next-page (UNBOUND)
  * Bug fixes
  - Fix theme configuration via Common Settings Menu
  - Honor the value of environment variables $XDG_DATA_HOME,
    $XDG_CONFIG_HOME and $XDG_CACHE_HOME for the Flatpak
  * UI/UX
  - Add cursor change on hover for buttons and links in internal pages and panel buffers
  - Improve user experience of pick-color (UNBOUND)
* Tue Jun 27 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to version 3.3.0:
  * Features
  - Change default search engine to Atlas' own SearXNG instance
  - Add command pick-color (UNBOUND), to pick a color and copy its
    HEX, RGB or HSL code to clipboard
  - Add keybindings for commands delete-panel-buffer (f4)
    and delete-all-panel-buffers (s-f4)
  - Improve describe-prompt-buffer (UNBOUND):
    List available keybindings for enabled prompt buffer modes
    Reference current prompt buffer sources
  * Bug fixes
  - Honor the value of zoom-ratio-default
  - Honor the value of the panel buffer's style
  - Fix bugs in the common settings interface
  - Fix clipboard support for the Flatpak on Wayland
  - Fix behavior of hint-mode when slots hinting-type and
    show-hint-scope-p are set to :vi and t, respectively
  * UI
  - Add border between panel buffer and main content area
  - Apply nuanced background color to panel buffers
  * Programming interface
  - external-editor-program no longer signals when the program is
    a string containing spaces
  - external-editor-program returns its value rather than returning
    a string value in a list
* Thu Jun 22 2023 Michael Pujos <pujos.michael@gmail.com>
- added patch for dynamically loading versioned libfixposix and libwebkit2gtk-4.1
* Mon Jun 19 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to version 3.2.1:
  * bug fixes only
* Thu Jun 15 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to version 3.2.0:
  * Add support for PDF.js
  * Add command toggle-suggestions-display ( UNBOUND ),
    that allows collapsing the prompt buffer to its input area
  * Improve the UI of the REPL
  * Output multiple values when evaluating Lisp expressions from execute-command ( C-space )
  * Bug fixes
* Mon May 29 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to version 3.1.0
* Fri May 19 2023 Michael Pujos <pujos.michael@gmail.com>
- Initial release
